#!/bin/bash
#Automatically Created by buildpkg 1.7.0
#Maintainer: Paul Marwick (toothandnail) <paulm-AT-waitrose-DOT-com>
#Former Maintainer(s): gmg (g.monpontet@gmail.com)
#url: http://www.wireshark.org/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{txz,tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.$PKGEXTENSION
	cd $startdir
	md5sum $package.$PKGEXTENSION > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/stor/build/zenwalk/wireshark/1.4.1/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/zip*)
					cmd="unzip" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	cd $startdir/src/$pkgname-$pkgver
	./configure --prefix=/usr --localstatedir=/var --sysconfdir=/etc --disable-usr-local --enable-setuid-install
	make || return 1
	make install DESTDIR=$startdir/pkg
mkdir -p $startdir/pkg/usr/share/applications

cat << EOF >> $startdir/pkg/usr/share/applications/wireshark.desktop
[Desktop Entry]
Type=Application
Version=1.0
Name=Wireshark
Name[vi]=Wireshark
GenericName=Network Analyzer
GenericName[af]=Netwerk Analiseerder
GenericName[az]=Şəbəkə Analiz Proqramı
GenericName[bg]=Анализатор на мрежови трафик
GenericName[bs]=Mrežni analizer
GenericName[ca]=Analitzador de xarxa
GenericName[cs]=Analyzátor sítě
GenericName[da]=Netværksanalyse
GenericName[de]=Programm für die Netzwerk-Analyse
GenericName[el]=Αναλυτής Δικτύων
GenericName[en_GB]=Network Analyser
GenericName[eo]=Retanalizilo
GenericName[es]=Analizador de redes
GenericName[et]=Võrguliikluse analüsaator
GenericName[eu]=Sare ikerketaria
GenericName[fa]=تحلیلگر شبکه
GenericName[fi]=Verkkoanalysaattori
GenericName[fr]=Analyseur réseau
GenericName[he]=מאבחן רשת
GenericName[hr]=Program za analiziranje mreža
GenericName[hu]=hálózatanalizáló
GenericName[id]=Analisis jaringan
GenericName[is]=Netskoðunartól
GenericName[it]=Analizzatore di rete
GenericName[ja]=ネットワークアナライザ
GenericName[ko]=네트웍 분석기
GenericName[lo]=ເຄື່ອງມືວິເຄາະເຄືອຂ່າຍ
GenericName[lt]=Tinklo analizatorius
GenericName[lv]=Tīkla Analizators
GenericName[mk]=Анализатор на мрежи
GenericName[mn]=Сүлжээ-шинжлэлийн програм
GenericName[mt]=Analizzatur tan-network
GenericName[nb]=Nettverksanalysator
GenericName[nl]=netwerkanalyseprogramma
GenericName[nn]=Nettverksanalysator
GenericName[nso]=Moahlaahli wa Kgokagano
GenericName[pl]=Analizator sieci
GenericName[pt]=Analisador de Redes
GenericName[pt_BR]=Analisador de rede
GenericName[ro]=Analizor de reţea
GenericName[ru]=Анализатор сетевого трафика
GenericName[se]=Fierbmeanalysa
GenericName[sk]=Analyzátor siete
GenericName[sl]=Analizator omrežij
GenericName[sr]=Analizatror mreže
GenericName[ss]=Sihlatiyi seluchungechunge
GenericName[sv]=Nätverksanalyserare
GenericName[ta]=Å¨Ä ¬öÅ¡Ç÷
GenericName[th]=เครื่องมือวิเคราะห์เครือข่าย
GenericName[tr]=Ağ Analiz Programı
GenericName[uk]=Аналізатор мережі
GenericName[ven]=Musengulusi wa Vhukwamani
GenericName[vi]=Trình phân tích  mạng
GenericName[xh]=Umcukucezi Womsebenzi womnatha
GenericName[zh_CN]=网络分析程序
GenericName[zh_TW]=網路分析程式
GenericName[zu]=Umhloli Woxhumano olusakazekile
Comment=Network traffic analyzer
Comment[fi]=Verkkoliikenne analysaattori
Comment[fr]=Analyseur de trafic réseau
Comment[sv]=Nätverkstrafikanalysator
Icon=wireshark
TryExec=wireshark
Exec=wireshark
Terminal=false
Categories=Network;Monitor;

EOF
mkdir -p $startdir/pkg/usr/share/icons/hicolor/16x16/apps
mkdir -p $startdir/pkg/usr/share/icons/hicolor/32x32/apps
mkdir -p $startdir/pkg/usr/share/icons/hicolor/48x48/apps

cp $startdir/src/$pkgname-$pkgver/image/hi16-app-wireshark.png $startdir/pkg/usr/share/icons/hicolor/16x16/apps/wireshark.png
cp $startdir/src/$pkgname-$pkgver/image/hi32-app-wireshark.png $startdir/pkg/usr/share/icons/hicolor/32x32/apps/wireshark.png
cp $startdir/src/$pkgname-$pkgver/image/hi48-app-wireshark.png $startdir/pkg/usr/share/icons/hicolor/48x48/apps/wireshark.png
} 

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
wireshark: Wireshark is the world's most popular network protocol analyzer.
wireshark: 
wireshark: It has a rich and powerful feature set and runs on most computing
wireshark: platforms including Windows, OS X, and Linux. Network professionals,
wireshark: security experts, developers, and educators around the world use it
wireshark: regularly. It is freely available as open source, and is released
wireshark: under the GNU General Public License
wireshark: 
wireshark: 
wireshark: 
wireshark: 
EODESC
}

copy_docs() {
	for stuff in ${docs[@]}; do
		if [ ! -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
			mkdir -p $startdir/pkg/usr/doc/$pkgname-$pkgver
		fi
		find $startdir/src -type f -iname "$stuff" -exec cp -R '{}' $startdir/pkg/usr/doc/$pkgname-$pkgver \;
	done
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(requiredbuilder -z $startdir/$package.$PKGEXTENSION)
	
	depstring=$depends
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.7.0
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

PKGEXTENSION=txz

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=wireshark
pkgver=1.4.1
pkgrel=1
zenver=66
arch=i686
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
source=("http://media-2.cacetech.com/wireshark/src/wireshark-1.4.1.tar.bz2")
sourcetemplate=http://zenwalk.pinguix.com/user-accounts/toothandnail//wireshark/1.4.1
docs=(readme* install* copying changelog authors news todo faq)
export CFLAGS="-O2 -march=i686 -mtune=i686"
export CXXFLAGS="-O2 -march=i686 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
copy_docs
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
